@@ -34,11 +34,14 @@ void  on_table_selection_changed   (GtkTreeSelection*, gpointer);
 void  on_iface_properties_clicked  (GtkWidget*, gpointer);
 
 void  on_iface_active_changed      (GtkWidget*, gpointer);
+void  on_iface_roaming_changed     (GtkWidget *widget, gpointer data);
+
 void  on_bootproto_changed         (GtkWidget*, gpointer);
-void  on_connection_cancel_clicked (GtkWidget*, gpointer);
-void  on_connection_ok_clicked     (GtkWidget*, gpointer);
 void  on_detect_modem_clicked      (GtkWidget*, gpointer);
-gboolean on_connection_dialog_close (GtkWidget*, GdkEvent*, gpointer);
+void  on_connection_response       (GtkWidget *widget,
+				    gint       response,
+				    gpointer   data);
+
 
 gboolean on_table_button_press (GtkWidget*, GdkEventButton*, gpointer);
 gboolean on_table_popup_menu   (GtkWidget*, gpointer);
@@ -66,4 +69,8 @@ gboolean on_domain_focus_out   (GtkWidget     *widget,
 				GdkEventFocus *event,
 				gpointer       data);
 
+void on_ppp_type_changed    (GtkWidget *widget,
+			     gpointer   data);
+
+
 #endif /* __CALLBACKS_H */
