@@ -56,9 +56,9 @@ static void
 gst_network_tool_init (GstNetworkTool *tool)
 {
   tool->hosts_config = OOBS_HOSTS_CONFIG (oobs_hosts_config_get ());
-  gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (tool->hosts_config));
+  gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (tool->hosts_config), TRUE);
   tool->ifaces_config = OOBS_IFACES_CONFIG (oobs_ifaces_config_get ());
-  gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (tool->ifaces_config));
+  gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (tool->ifaces_config), TRUE);
 
   tool->bus_connection = dbus_bus_get (DBUS_BUS_SYSTEM, NULL);
 
@@ -90,7 +90,7 @@ save_dns (GList *list, gpointer data)
   GstNetworkTool *tool = (GstNetworkTool *) data;
 
   oobs_hosts_config_set_dns_servers (tool->hosts_config, list);
-  oobs_object_commit (OOBS_OBJECT (tool->hosts_config));
+  gst_tool_commit (GST_TOOL (tool), OOBS_OBJECT (tool->hosts_config));
 }
 
 static void
@@ -99,7 +99,7 @@ save_search_domains (GList *list, gpointer data)
   GstNetworkTool *tool = (GstNetworkTool *) data;
 
   oobs_hosts_config_set_search_domains (tool->hosts_config, list);
-  oobs_object_commit (OOBS_OBJECT (tool->hosts_config));
+  gst_tool_commit (GST_TOOL (tool), OOBS_OBJECT (tool->hosts_config));
 }
 
 static GObject*
