@@ -26,7 +26,9 @@
 #include "user-settings.h"
 #include "group-settings.h"
 
-#define PROFILES_FILE "/etc/gnome-system-tools/users/profiles"
+extern GstTool *tool;
+
+#define PROFILES_FILE CONF_DIR "/user-profiles.conf"
 #define GST_USER_PROFILES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GST_TYPE_USER_PROFILES, GstUserProfilesPrivate))
 
 typedef struct _GstUserProfilesPrivate GstUserProfilesPrivate;
@@ -64,15 +66,15 @@ create_profile (GKeyFile    *key_file,
 	GstUserProfile *profile;
 
 	profile = g_new0 (GstUserProfile, 1);
-	profile->name = g_key_file_get_locale_string (key_file, group, "name", NULL, NULL);
+	profile->name = g_key_file_get_locale_string (key_file, group, "Name", NULL, NULL);
 	profile->description = g_key_file_get_locale_string (key_file, group,
-	                                                     "description", NULL, NULL);
-	profile->is_default = g_key_file_get_boolean (key_file, group, "default", NULL);
-	profile->shell = g_key_file_get_string (key_file, group, "shell", NULL);
-	profile->home_prefix = g_key_file_get_string (key_file, group, "home-prefix", NULL);
-	profile->groups = g_key_file_get_string_list (key_file, group, "groups", NULL, NULL);
-	profile->uid_min = g_key_file_get_integer (key_file, group, "uid-min", NULL);
-	profile->uid_max = g_key_file_get_integer (key_file, group, "uid-max", NULL);
+	                                                     "Description", NULL, NULL);
+	profile->is_default = g_key_file_get_boolean (key_file, group, "Default", NULL);
+	profile->shell = g_key_file_get_string (key_file, group, "Shell", NULL);
+	profile->home_prefix = g_key_file_get_string (key_file, group, "HomePrefix", NULL);
+	profile->groups = g_key_file_get_string_list (key_file, group, "Groups", NULL, NULL);
+	profile->uid_min = g_key_file_get_integer (key_file, group, "MinUID", NULL);
+	profile->uid_max = g_key_file_get_integer (key_file, group, "MaxUID", NULL);
 
 	return profile;
 }
@@ -129,10 +131,14 @@ static void
 free_profile (GstUserProfile *profile)
 {
 	g_free (profile->name);
-	g_free (profile->description);
-	g_free (profile->shell);
-	g_free (profile->home_prefix);
-	g_strfreev (profile->groups);
+	if (profile->description)
+		g_free (profile->description);
+	if (profile->shell)
+		g_free (profile->shell);
+	if (profile->home_prefix)
+		g_free (profile->home_prefix);
+	if (profile->groups)
+		g_strfreev (profile->groups);
 	g_free (profile);
 }
 
@@ -240,9 +246,10 @@ gst_user_profiles_get_for_user (GstUserProfiles *profiles,
 	GstUserProfilesPrivate *priv;
 	GstUserProfile *profile;
 	GstUserProfile *matched;
+	OobsGroupsConfig *groups_config;
 	GFile *file_home, *file_prefix;
 	const gchar *shell, *home;
-	gint uid;
+	uid_t uid;
 	gchar **group_name;
 	OobsGroup *group;
 	GList *l, *m;
@@ -256,6 +263,7 @@ gst_user_profiles_get_for_user (GstUserProfiles *profiles,
 	uid = oobs_user_get_uid (user);
 
 	priv = GST_USER_PROFILES_GET_PRIVATE (profiles);
+	groups_config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
 
 	matched = NULL;
 	for (l = priv->profiles; l; l = l->next) {
@@ -264,26 +272,29 @@ gst_user_profiles_get_for_user (GstUserProfiles *profiles,
 		/* also check for settings that should not be changed for existing users */
 		if (strict)
 		  {
-			  /* check that UID is in the range */
-			  if (!(profile->uid_min <= uid && uid <= profile->uid_max))
+			  /* check that UID is in the range, when UID range is set and valid */
+			  if ((profile->uid_min < profile->uid_max)
+			      && !(profile->uid_min <= uid && uid <= profile->uid_max))
 				  continue;
 
-			  /* check that home is under the prefix */
-			  file_home = g_file_new_for_path (home);
-			  file_prefix = g_file_new_for_path (profile->home_prefix);
-			  if (!g_file_has_prefix (file_home, file_prefix)) {
-				  g_object_unref (file_home);
-				  g_object_unref (file_prefix);
-				  continue;
-			  }
-			  else {
-				  g_object_unref (file_home);
-				  g_object_unref (file_prefix);
+			  /* check that home is under the prefix, when home prefix is set */
+			  if (profile->home_prefix) {
+				  file_home = g_file_new_for_path (home);
+				  file_prefix = g_file_new_for_path (profile->home_prefix);
+				  if (!g_file_has_prefix (file_home, file_prefix)) {
+					  g_object_unref (file_home);
+					  g_object_unref (file_prefix);
+					  continue;
+				  }
+				  else {
+					  g_object_unref (file_home);
+					  g_object_unref (file_prefix);
+				  }
 			  }
 		  }
 
-		/* check that shell is the right one */
-		if (strcmp (shell, profile->shell) != 0)
+		/* check that shell is the right one, when shell is set */
+		if (profile->shell && strcmp (shell, profile->shell) != 0)
 			continue;
 
 		/* check user's membership to all groups of the profile,
@@ -300,15 +311,15 @@ gst_user_profiles_get_for_user (GstUserProfiles *profiles,
 				group_name++;
 			}
 
-			group = group_settings_get_group_from_name ((char *) m->data);
-			in_group = user_settings_is_user_in_group (user, group);
+			group = oobs_groups_config_get_from_name (groups_config, (char *) m->data);
+			in_group = oobs_user_is_in_group (user, group);
 			if ((in_profile && !in_group) || (!in_profile && in_group)) {
-				if (group)
-					g_object_unref (group);
-
 				matched_groups = FALSE;
 				break;
 			}
+
+			if (group)
+				g_object_unref (group);
 		}
 
 		/* stop at first match, since the list has been reverted on loading,
@@ -335,6 +346,8 @@ gst_user_profiles_apply (GstUserProfiles *profiles,
                          gboolean         new_user)
 {
 	GstUserProfilesPrivate *priv;
+	OobsUsersConfig *users_config;
+	OobsGroupsConfig *groups_config;
 	gint uid;
 	char *home;
 	char **group_name;
@@ -349,9 +362,7 @@ gst_user_profiles_apply (GstUserProfiles *profiles,
 	g_return_if_fail (oobs_user_get_login_name (user) != NULL);
 
 	priv = GST_USER_PROFILES_GET_PRIVATE (profiles);
-
-	/* default shell */
-	oobs_user_set_shell (user, profile->shell);
+	groups_config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
 
 	/* add user to groups from the profile, remove it from groups of other profiles */
 	for (l = priv->all_groups; l; l = l->next) {
@@ -364,25 +375,34 @@ gst_user_profiles_apply (GstUserProfiles *profiles,
 			group_name++;
 		}
 
-		group = group_settings_get_group_from_name ((char *) l->data);
+		group = oobs_groups_config_get_from_name (groups_config, (char *) l->data);
 		if (in_profile)
 			oobs_group_add_user (group, user);
 		else
 			oobs_group_remove_user (group, user);
 	}
 
+	/* default shell */
+	if (profile->shell)
+		oobs_user_set_shell (user, profile->shell);
+
 	if (!new_user) /* don't apply settings below to existing users */
 		return;
 
-	/* default UID */
-	uid = user_settings_find_new_uid (profile->uid_min, profile->uid_max);
-	oobs_user_set_uid (user, uid);
+	/* default UID, G_MAXUINT32 indicates we want the default value from the system */
+	if (profile->uid_min != 0 || profile->uid_max != 0) {
+		users_config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
+		uid = oobs_users_config_find_free_uid (users_config, profile->uid_min, profile->uid_max);
+		oobs_user_set_uid (user, uid);
+	}
 
 	/* default home prefix */
-	home = g_build_path (G_DIR_SEPARATOR_S,
-			     profile->home_prefix,
-			     oobs_user_get_login_name (user),
-			     NULL);
-	oobs_user_set_home_directory (user, home);
-	g_free (home);
+	if (profile->home_prefix) {
+		home = g_build_path (G_DIR_SEPARATOR_S,
+		                     profile->home_prefix,
+		                     oobs_user_get_login_name (user),
+		                     NULL);
+		oobs_user_set_home_directory (user, home);
+		g_free (home);
+	}
 }
