@@ -38,6 +38,7 @@
 #include "table.h"
 #include "callbacks.h"
 #include "user-settings.h"
+#include "user-password.h"
 #include "privileges-table.h"
 #include "groups-table.h"
 #include "group-settings.h"
@@ -46,8 +47,21 @@
 
 extern GstTool *tool;
 
-void   on_edit_user_passwd  (GtkButton *button,
-                             gpointer   user_data);
+
+void   on_user_settings_enable_account  (GtkButton *button,
+                                         gpointer   user_data);
+void   on_user_new_name_changed         (GtkEditable *user_name,
+                                         gpointer     user_data);
+void   on_user_new_login_changed        (GtkComboBox *login_combo,
+                                         gpointer     user_data);
+void   on_user_new                      (GtkButton *button,
+                                         gpointer   user_data);
+void   on_edit_user_name                (GtkButton *button,
+                                         gpointer   user_data);
+void   on_edit_user_profile             (GtkButton *button,
+                                         gpointer   user_data);
+void   on_edit_user_advanced            (GtkButton *button,
+                                         gpointer   user_data);
 
 
 static gboolean
@@ -184,7 +198,8 @@ on_user_delete_clicked (GtkButton *button, gpointer user_data)
 	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->users_config))
 		return;
 
-	list = elem = table_get_row_references (TABLE_USERS, &model);
+	list = elem = users_table_get_row_references ();
+	model = users_table_get_model ();
 
 	while (elem) {
 		path = gtk_tree_row_reference_get_path (elem->data);
@@ -289,8 +304,14 @@ user_settings_show (OobsUser *user)
 	GtkWidget *face_image;
 	GtkWidget *profile_label;
 	GtkWidget *profile_button;
+	GtkWidget *passwd_label;
+	GtkWidget *disabled_image;
+	GtkWidget *disabled_label;
+	GtkWidget *enable_button;
 	GdkPixbuf *face;
 	GstUserProfile *profile;
+	OobsGroupsConfig *groups_config;
+	OobsGroup *group;
 
 	name_label = gst_dialog_get_widget (tool->main_dialog, "user_settings_real_name");
 	gtk_label_set_text (GTK_LABEL (name_label), oobs_user_get_full_name (user));
@@ -313,6 +334,41 @@ user_settings_show (OobsUser *user)
 		gtk_label_set_text (GTK_LABEL (profile_label),
 		                    profile ? profile->name : _("Custom"));
 	}
+
+	passwd_label = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd");
+	groups_config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
+	group = oobs_groups_config_get_from_name (groups_config, NO_PASSWD_LOGIN_GROUP);
+
+	if (oobs_user_get_password_empty (user))
+		/* TRANSLATORS: This applies to a password. */
+		gtk_label_set_text (GTK_LABEL (passwd_label), _("None"));
+	else if (oobs_user_is_in_group (user, group))
+		/* TRANSLATORS:  This applies to a password. Keep the string short. */
+		gtk_label_set_text (GTK_LABEL (passwd_label), _("Not asked on login"));
+	else
+		gtk_label_set_text (GTK_LABEL (passwd_label), _("Asked on login"));
+
+	/* Show notice if account is locked, this is really useful for new accounts
+	 * where user did not choose a password. */
+	disabled_image = gst_dialog_get_widget (tool->main_dialog,
+	                                        "user_settings_disabled_account_image");
+	disabled_label = gst_dialog_get_widget (tool->main_dialog,
+	                                        "user_settings_disabled_account");
+	enable_button = gst_dialog_get_widget (tool->main_dialog,
+	                                       "user_settings_enable_account");
+
+	if (oobs_user_get_password_disabled (user)) {
+		gtk_widget_show (disabled_image);
+		gtk_widget_show (disabled_label);
+		gtk_widget_show (enable_button);
+	}
+	else {
+		gtk_widget_hide (disabled_image);
+		gtk_widget_hide (disabled_label);
+		gtk_widget_hide (enable_button);
+	}
+
+	g_object_unref (group);
 }
 
 static void
@@ -510,6 +566,8 @@ user_settings_check_revoke_admin_rights ()
 		return (response == GTK_RESPONSE_OK);
 	}
 
+	g_object_unref (admin_group);
+
 	return TRUE;
 }
 
@@ -537,9 +595,42 @@ check_profile (OobsUser *user, GstUserProfile *profile)
 			  return user_settings_check_revoke_admin_rights (user);
 	  }
 
+	g_object_unref (admin_group);
+
 	return TRUE;
 }
 
+/*
+ * Callback for user_settings_enable_account: unlock account and commit changes.
+ */
+void
+on_user_settings_enable_account  (GtkButton *enable_button,
+                                  gpointer   user_data)
+{
+	GtkWidget *disabled_image;
+	GtkWidget *disabled_label;
+	OobsUser *user;
+
+	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->users_config))
+		return;
+
+	user = users_table_get_current ();
+	oobs_user_set_password_disabled (user, FALSE);
+
+	if (gst_tool_commit (tool, OOBS_OBJECT (user)) == OOBS_RESULT_OK) {
+		disabled_image = gst_dialog_get_widget (tool->main_dialog,
+		                                        "user_settings_disabled_account_image");
+		disabled_label = gst_dialog_get_widget (tool->main_dialog,
+		                                        "user_settings_disabled_account");
+
+		gtk_widget_hide (disabled_image);
+		gtk_widget_hide (disabled_label);
+		gtk_widget_hide (GTK_WIDGET (enable_button));
+	}
+
+	g_object_unref (user);
+}
+
 /*
  * Callback for user_new_name entry: on every change, fill the combo entry
  * with proposed logins. Also update validate button's sensitivity if name is empty.
@@ -892,6 +983,7 @@ on_user_new (GtkButton *button, gpointer user_data)
 	user = oobs_user_new (login);
 	oobs_user_set_full_name (user, fullname);
 	oobs_user_set_encrypted_home (user, encrypt);
+	oobs_user_set_home_flags (user, OOBS_USER_CHOWN_HOME);
 
 	g_return_if_fail (user != NULL);
 
@@ -899,6 +991,10 @@ on_user_new (GtkButton *button, gpointer user_data)
 	profile = gst_user_profiles_get_default_profile (GST_USERS_TOOL (tool)->profiles);
 	gst_user_profiles_apply (GST_USERS_TOOL (tool)->profiles, profile, user, TRUE);
 
+	/* We need to know about this user before adding it, else we won't be aware
+	 * that we triggered the commit, and we will show a "Reload config?" dialog. */
+	gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (user), FALSE);
+
 	/* Commit both user and groups config because of possible memberships
 	 * added by the profile. Avoid showing the new user or trying to commit
 	 * group changes if the user has not been created. */
@@ -1211,7 +1307,7 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_group");
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
 
-	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter) != -1) {
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter)) {
 		gtk_tree_model_get (model, &iter,
 				    COL_GROUP_OBJECT, &main_group,
 				    -1);
